package com.alihealth.d2d.provtest.domain;

import com.alihealth.d2d.provtest.domain.eto.BASQXQ;
import com.alihealth.d2d.provtest.utils.LocalDateDeserializer;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlElementWrapper;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
import lombok.Data;

import javax.persistence.Transient;

/**
 * <p>
 * 国产药品基本信息数据子集
 * </p>
 *
 * @author Jason
 * @since 2025-06-06
 */
@Data
@TableName("domestic_drug_base_info")
public class DomesticDrugBaseInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键ID
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 事件流水号
     */
    private String eventId;

    /**
     * 国家药品标识码
     */
    @JacksonXmlProperty(localName = "GJYPBSM")
    private String gjypbsm;

    /**
     * 药品通用名称
     */
    @JacksonXmlProperty(localName = "YPTYMC")
    private String yptymc;

    /**
     * 药品英文名称
     */
    @JacksonXmlProperty(localName = "YPYWMC")
    private String ypywmc;

    /**
     * 药品商品名称
     */
    @JacksonXmlProperty(localName = "YPSPMC")
    private String ypspmc;

    /**
     * 药品本位码
     */
    @JacksonXmlProperty(localName = "YPBWM")
    private String ypbwm;

    /**
     * 剂型
     */
    @JacksonXmlProperty(localName = "JX")
    private String jx;

    /**
     * 制剂规格
     */
    @JacksonXmlProperty(localName = "ZJGG")
    private String zjgg;

    /**
     * 包装规格
     */
    @JacksonXmlProperty(localName = "BZGG")
    private String bzgg;

    /**
     * 包装转换比
     */
    @JacksonXmlProperty(localName = "BZZHB")
    private BigDecimal bzzhb;

    /**
     * 包装规格标识
     */
    @JacksonXmlProperty(localName = "BZGGBS")
    private String bzggbs;

    /**
     * 药品有效期
     */
    @JacksonXmlProperty(localName = "YPYXQ")
    private Integer ypyxq;

    /**
     * 药品有效期单位
     */
    @JacksonXmlProperty(localName = "YPYXQDW")
    private String ypyxqdw;

    /**
     * 药品批准文号
     */
    @JacksonXmlProperty(localName = "YPPZWH")
    private String yppzwh;

    /**
     * 药品批准文号有效期
     */
    @JacksonXmlProperty(localName = "YPPZWHYXQ")
    @JsonDeserialize(using = LocalDateDeserializer.class)
    private LocalDate yppzwhyxq;

    /**
     * 药品注册分类
     */
    @JacksonXmlProperty(localName = "YPZCFL")
    private String ypzcfl;

    /**
     * 国家基本药物标识
     */
    @JacksonXmlProperty(localName = "GJJBYWBS")
    private String gjjbywbs;

    /**
     * 特殊药品管理分类
     */
    @JacksonXmlProperty(localName = "TSYPGLFL")
    private String tsypglfl;

    /**
     * 处方药标识
     */
    @JacksonXmlProperty(localName = "CFYBS")
    private String cfybs;

    /**
     * 统一社会信用代码(境内药品生产企业)
     */
    @JacksonXmlProperty(localName = "TYSHXYDMJNYPSCQY")
    private String tyshxydmjnypscqy;

    /**
     * 统一社会信用代码（境内药品上市许可持有人）
     */
    @JacksonXmlProperty(localName = "TYSHXYDMJNYPSSXKCYR")
    private String tyshxydmjnypssxkcyr;

    /**
     * 暂无
     */
    @JacksonXmlProperty(localName = "SCZT")
    private String sczt;

    /**
     * 暂无
     */
    @JacksonXmlProperty(localName = "BZZHBDW")
    private String bzzhbdw;

    /**
     * 子集：bzbl-包装比例 、bzjb-包装级别 、ypbsm-药品标识码
     */
    //@JacksonXmlProperty(localName = "BASQXQS")
    private String basqxqs;

    // XML映射字段（不直接存入数据库）
    @TableField(exist = false)
    @JacksonXmlElementWrapper(localName = "BASQXQS")
    @JacksonXmlProperty(localName = "BASQXQ")
    private List<BASQXQ> basqxqList;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 是否删除(0-否 1-是)
     */
    private Integer isDeleted;

    // 在setter方法中完成转换
    public void setBasqxqList(List<BASQXQ> basqxqList) {
        this.basqxqList = basqxqList;
        try {
            this.basqxqs = new ObjectMapper().writeValueAsString(basqxqList);
        } catch (JsonProcessingException e) {
            throw new RuntimeException("转换BASQXQS为JSON失败", e);
        }
    }



}
