package com.alihealth.d2d.provtest.service.handle;

import com.alihealth.d2d.provtest.entity.EventBody;
import com.alihealth.d2d.provtest.entity.InstanceDetail;
import com.alihealth.d2d.provtest.entity.ItemDetail;
import com.alihealth.d2d.provtest.entity.VTTSEventS;
import com.baomidou.mybatisplus.extension.service.IService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Jason
 * @date 2025年06月05日 11:11:15
 */
public abstract class AbstractEventDataHandler<T> implements EventDataHandler {

    protected final Logger log = LoggerFactory.getLogger(getClass());

    protected abstract Class<T> getEntityClass();

    protected abstract IService<T> getService();

    protected abstract T convertToEntity(EventBody eventBody, ItemDetail item, InstanceDetail detail);

    @Override
    public void handle(VTTSEventS eventS) {
        List<T> entities = new ArrayList<>();

        for (EventBody eventBody : eventS.getVttsEvent().getEventBodyList()) {
            if (eventBody.getItemList() != null) {
                for (ItemDetail item : eventBody.getItemList()) {
                    if (item.getInstanceList() != null) {
                        for (InstanceDetail instance : item.getInstanceList()) {
                            try {
                                entities.add(convertToEntity(eventBody, item, instance));
                            } catch (Exception e) {
                                log.error("转换实体失败", e);
                            }
                        }
                    } else {
                        try {
                            entities.add(convertToEntity(eventBody, item, null));
                        } catch (Exception e) {
                            log.error("转换实体失败", e);
                        }
                    }

                }
            } else {
                try {
                    entities.add(convertToEntity(eventBody, null, null));
                } catch (Exception e) {
                    log.error("转换实体失败", e);
                }
            }
        }

        if (!entities.isEmpty()) {
            getService().saveBatch(entities);
        }
    }
}
