package com.alihealth.d2d.provtest.service.handle.business;

import com.alihealth.d2d.provtest.domain.DomesticDrugProductionApplyInfo;
import com.alihealth.d2d.provtest.domain.DrugImportApplyInfo;
import com.alihealth.d2d.provtest.entity.EventBasic;
import com.alihealth.d2d.provtest.entity.EventBody;
import com.alihealth.d2d.provtest.entity.InstanceDetail;
import com.alihealth.d2d.provtest.entity.ItemDetail;
import com.alihealth.d2d.provtest.service.IDomesticDrugProductionApplyInfoService;
import com.alihealth.d2d.provtest.service.IDrugImportApplyInfoService;
import com.alihealth.d2d.provtest.service.handle.AbstractEventDataHandler;
import com.alihealth.d2d.provtest.service.handle.EventSubType;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Date;

/**
 * @author Jason
 * @date 2025年06月05日 11:37:18
 */
@Service
@EventSubType("2012")
public class SubType2012Handler extends AbstractEventDataHandler<DrugImportApplyInfo> {

    @Autowired
    private IDrugImportApplyInfoService service;

    @Override
    protected Class<DrugImportApplyInfo> getEntityClass() {
        return DrugImportApplyInfo.class;
    }

    @Override
    protected IService<DrugImportApplyInfo> getService() {
        return service;
    }

    @Override
    protected DrugImportApplyInfo convertToEntity(EventBody eventBody, ItemDetail item, InstanceDetail instance) {
        EventBasic evtBasic = eventBody.getEvtBasic();
        //时间格式
        SimpleDateFormat formatterDatetime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        //日期格式
        SimpleDateFormat formatterDate = new SimpleDateFormat("yyyyMMdd");
        try {
            return DrugImportApplyInfo.builder()
                    .eventId(eventBody.getEventID())

                    .rksj(evtBasic.getString("RKSJ") != null ? formatterDatetime.parse(evtBasic.getString("RKSJ")) : null)
                    .recTime(formatterDatetime.parse(eventBody.getRecTime()))
                    .rkdbh(evtBasic.getString("RKDBH"))

                    .ypzsm(instance.getString("YPZSM"))
                    .syjbzypzsm(instance.getString("SYJBZYPZSM"))
                    .bzcj(instance.getString("BZCJ"))
                    .ymzt(instance.getString("YMZT"))

                    .tyshxydmjkymdlqy(item.getString("TYSHXYDMJKYMDLQY"))
                    .jkymdlqymc(item.getString("JKYMDLQYMC"))
                    .jwypssxkcyrdm(item.getString("JWYPSSXKCYRDM"))
                    .jwypssxkcyrmczw(item.getString("JWYPSSXKCYRMCZW"))
                    .jwypscqydm(item.getString("JWYPSCQYDM"))
                    .jwypscqymczw(item.getString("JWYPSCQYMCZW"))
                    .tyshxydmfbzc(item.getString("TYSHXYDMFBZC"))
                    .fbzcmc(item.getString("FBZCMC"))
                    .yptymc(item.getString("YPTYMC"))
                    .gjypbsm(item.getString("GJYPBSM"))
                    .ymscph(item.getString("YMSCPH"))
                    .scrq(formatterDate.parse(item.getString("SCRQ")))
                    .ymyxqjzrq(formatterDate.parse(item.getString("YMYXQJZRQ")))

                    .scsl(item.getInt("SCSL"))
                    .build();
        } catch (ParseException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public String getSubType() {
        return "2012";
    }

    @Override
    public void handleBase(String xml, String eventId) {

    }
}
